CardinalityOne

Trait CardinalityOne 

pub trait CardinalityOne<S: Scope> {
    // Required method
    fn cardinality_one(&self) -> Collection<S, (Value, Value), isize>;
}
Provides the cardinality_one method.

Required Methods

fn cardinality_one(&self) -> Collection<S, (Value, Value), isize>

Ensures that only a single value per eid exists within an attribute, by retracting any previous values upon new updates. Therefore this stream does not expect explicit retractions.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<S> CardinalityOne<S> for Collection<S, (Value, Value), isize>
where S: Scope, S::Timestamp: Lattice + Ord,

Implementors