plan_order

Function plan_order 

pub fn plan_order(
    source_index: usize,
    bindings: &[Binding],
) -> (Vec<u32>, Vec<Binding>)
Orders the variables s.t. each has at least one binding from itself to a prior variable. source_binding indicates the binding from which we will source the prefixes in the resulting delta pipeline. Returns the chosen variable order and the corresponding binding order.

(adapted from github.com/frankmcsherry/dataflow-join/src/motif.rs)