Sinkable

Trait Sinkable 

pub trait Sinkable<T>
where T: Timestamp + Lattice + Into<Time>,
{ // Required method fn sink<S, P>( &self, stream: &Stream<S, ResultDiff<T>>, pact: P, probe: &mut ProbeHandle<T>, context: SinkingContext, ) -> Result<Option<Stream<S, Output>>, Error> where S: Scope<Timestamp = T>, P: ParallelizationContract<S::Timestamp, ResultDiff<T>>; }
An external system that wants to receive result diffs.

Required Methods

fn sink<S, P>( &self, stream: &Stream<S, ResultDiff<T>>, pact: P, probe: &mut ProbeHandle<T>, context: SinkingContext, ) -> Result<Option<Stream<S, Output>>, Error>
where S: Scope<Timestamp = T>, P: ParallelizationContract<S::Timestamp, ResultDiff<T>>,

Creates a timely operator feeding dataflow outputs to a specialized data sink.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> Sinkable<T> for Sink
where T: Timestamp + Lattice + Default + Into<Time>,