pub struct AttributeConfig {
pub input_semantics: InputSemantics,
pub trace_slack: Option<Time>,
pub index_direction: IndexDirection,
pub query_support: QuerySupport,
pub timeless: bool,
}Expand description
Per-attribute semantics.
Fields
input_semantics: InputSemanticsModifiers to apply on attribute inputs, such as keeping only the most recent value per eid, or compare-and-swap.
trace_slack: Option<Time>How close indexed traces should follow the computation frontier.
index_direction: IndexDirectionIndex directions to maintain for this attribute.
query_support: QuerySupportQuery capabilities supported by this attribute.
timeless: boolDoes this attribute care about its respective time dimension? Timeless attributes do not have an influence on the overall progress in the system.
Implementations
Sourceimpl AttributeConfig
impl AttributeConfig
Sourcepub fn tx_time(input_semantics: InputSemantics) -> Self
pub fn tx_time(input_semantics: InputSemantics) -> Self
Shortcut to specifying an attribute that will live in some transaction time domain and always compact up to the computation frontier.
Sourcepub fn real_time(input_semantics: InputSemantics) -> Self
pub fn real_time(input_semantics: InputSemantics) -> Self
Shortcut to specifying an attribute that will live in some real-time domain and always compact up to the computation frontier.
Sourcepub fn uncompacted(input_semantics: InputSemantics) -> Self
pub fn uncompacted(input_semantics: InputSemantics) -> Self
Shortcut to specifying an attribute that will live in an arbitrary time domain and never compact its trace.