pub trait CardinalityOne<S: Scope> {
// Required method
fn cardinality_one(&self) -> Collection<S, (Value, Value), isize>;
}Expand description
Provides the cardinality_one method.
Required Methods
Sourcefn cardinality_one(&self) -> Collection<S, (Value, Value), isize>
fn cardinality_one(&self) -> Collection<S, (Value, Value), isize>
Ensures that only a single value per eid exists within an attribute, by retracting any previous values upon new updates. Therefore this stream does not expect explicit retractions.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".