[−][src]Module declarative_dataflow::server::scheduler
Timer-based management of operator activators.
Structs
| Scheduler | A scheduler allows polling sources to defer triggering their activators, in case they do not have work available. This reduces time spent polling infrequently updated sources and allows us to (optionally) block for input from within the event loop without unnecessarily delaying sources that have run out of fuel during the current step. |