[][src]Trait declarative_dataflow::sinks::Sinkable

pub trait Sinkable<T> where
    T: Timestamp + Lattice + TotalOrder
{ fn sink<S, P>(
        &self,
        stream: &Stream<S, ResultDiff<T>>,
        pact: P
    ) -> Result<Stream<S, ResultDiff<T>>, Error>
    where
        S: Scope<Timestamp = T>,
        P: ParallelizationContract<S::Timestamp, ResultDiff<T>>
; }

An external system that wants to receive result diffs.

Required methods

fn sink<S, P>(
    &self,
    stream: &Stream<S, ResultDiff<T>>,
    pact: P
) -> Result<Stream<S, ResultDiff<T>>, Error> where
    S: Scope<Timestamp = T>,
    P: ParallelizationContract<S::Timestamp, ResultDiff<T>>, 

Creates a timely operator reading from the source andn producing inputs.

Loading content...

Implementors

impl Sinkable<u64> for Sink[src]

impl Sinkable<Duration> for Sink[src]

Loading content...