[−][src]Trait declarative_dataflow::sinks::Sinkable
An external system that wants to receive result diffs.
Required methods
fn sink<S, P>(
&self,
stream: &Stream<S, ResultDiff<T>>,
pact: P
) -> Result<Stream<S, ResultDiff<T>>, Error> where
S: Scope<Timestamp = T>,
P: ParallelizationContract<S::Timestamp, ResultDiff<T>>,
&self,
stream: &Stream<S, ResultDiff<T>>,
pact: P
) -> Result<Stream<S, ResultDiff<T>>, Error> where
S: Scope<Timestamp = T>,
P: ParallelizationContract<S::Timestamp, ResultDiff<T>>,
Creates a timely operator reading from the source andn producing inputs.
Implementors
impl Sinkable<u64> for Sink[src]
fn sink<S, P>(
&self,
stream: &Stream<S, ResultDiff<u64>>,
pact: P
) -> Result<Stream<S, ResultDiff<u64>>, Error> where
S: Scope<Timestamp = u64>,
P: ParallelizationContract<S::Timestamp, ResultDiff<u64>>, [src]
&self,
stream: &Stream<S, ResultDiff<u64>>,
pact: P
) -> Result<Stream<S, ResultDiff<u64>>, Error> where
S: Scope<Timestamp = u64>,
P: ParallelizationContract<S::Timestamp, ResultDiff<u64>>,
impl Sinkable<Duration> for Sink[src]
fn sink<S, P>(
&self,
stream: &Stream<S, ResultDiff<Duration>>,
pact: P
) -> Result<Stream<S, ResultDiff<Duration>>, Error> where
S: Scope<Timestamp = Duration>,
P: ParallelizationContract<S::Timestamp, ResultDiff<Duration>>, [src]
&self,
stream: &Stream<S, ResultDiff<Duration>>,
pact: P
) -> Result<Stream<S, ResultDiff<Duration>>, Error> where
S: Scope<Timestamp = Duration>,
P: ParallelizationContract<S::Timestamp, ResultDiff<Duration>>,